@@ -8,54 +8,54 @@ use std::fmt;
 use std::str::FromStr;
 
 #[derive(Debug)]
-pub struct KeyValueParseError {
+pub struct ParseError {
     details: String,
 }
 
-impl KeyValueParseError {
-    fn new(msg: &str) -> KeyValueParseError {
-        KeyValueParseError {
+impl ParseError {
+    fn new(msg: &str) -> ParseError {
+        ParseError {
             details: msg.to_string(),
         }
     }
 }
 
-impl fmt::Display for KeyValueParseError {
+impl fmt::Display for ParseError {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         write!(f, "{}", self.details)
     }
 }
 
-impl Error for KeyValueParseError {
+impl Error for ParseError {
     fn description(&self) -> &str {
         &self.details
     }
 }
 
-pub struct KeyValuePair {
+pub struct Pair {
     pub key: String,
     pub value: String,
 }
 
-impl fmt::Display for KeyValuePair {
+impl fmt::Display for Pair {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         write!(f, "'{}'='{}'", self.key, self.value)
     }
 }
 
-impl FromStr for KeyValuePair {
-    type Err = KeyValueParseError;
+impl FromStr for Pair {
+    type Err = ParseError;
 
     fn from_str(blob: &str) -> std::result::Result<Self, Self::Err> {
         let valid: Regex = Regex::new(r"^[^=\\0]+=[^=\\0]+$").unwrap();
         if valid.is_match(blob) {
             let mut parts = blob.split('=');
-            Ok(KeyValuePair {
+            Ok(Pair {
                 key: parts.next().unwrap().to_string(),
                 value: parts.next().unwrap().to_string(),
             })
         } else {
-            Err(KeyValueParseError::new(
+            Err(ParseError::new(
                 "Invalid key-value pair; exactly and only one '=' and no '\\0' is allowed",
             ))
         }
